@@ -179,9 +179,9 @@ class PTOpt:
               --optim-params [key=val [key=val ...]]
                   (default: [])
               --lr-sched-cls cls
-                  ({'LambdaLR'/'MultiplicativeLR'/'StepLR'/'MultiStepLR'/'Exponentia
-                  lLR'/'CosineAnnealingLR'/'CyclicLR'/'CosineAnnealingWarmRestarts'/
-                  'OneCycleLR'/'SWALR'} optional)
+                  ({'LambdaLR'/'MultiplicativeLR'/'StepLR'/'MultiStepLR'/
+                  'ExponentialLR'/'CosineAnnealingLR'/'CyclicLR'/
+                  'CosineAnnealingWarmRestarts'/'OneCycleLR'/'SWALR'} optional)
               --lr-sched-params [key=val [key=val ...]]
                   (default: [])
         """
